==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ListPanelItemModelDescriptionMetadata } from "./ListPanelItemModelDescriptionMetadata";
import { ListPanelTemplateItemUpdatingEventArgsDescription } from "./ListPanelTemplateItemUpdatingEventArgsDescription";
/**
 * @hidden
 */
var ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata, _super);
    function ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.b = function (a) {
        if (ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a == null) {
            ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.c(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a);
        }
        if (a.k(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a);
        ListPanelItemModelDescriptionMetadata.d(a);
    };
    ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.c = function (a) {
        a.item("Model", "ExportedType:ListPanelItemModel");
        a.item("ContentRef", "(w:Content,wf:Content)DataRef");
    };
    ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.d = function (a) {
        ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.b(a);
        a.ac("ListPanelTemplateItemUpdatingEventArgs", function () { return new ListPanelTemplateItemUpdatingEventArgsDescription(); });
        a.ab("ListPanelTemplateItemUpdatingEventArgs", ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a);
    };
    ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.$t = markType(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata, 'ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata');
    ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a = null;
    return ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata;
}(Base));
export { ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ListPanelItemModelDescriptionMetadata } from "./ListPanelItemModelDescriptionMetadata";
import { ListPanelTemplateItemUpdatingEventArgsDescription } from "./ListPanelTemplateItemUpdatingEventArgsDescription";
/**
 * @hidden
 */
var ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata, _super);
    function ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.b = function (a) {
        if (ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a == null) {
            ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.c(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a);
        }
        if (a.k(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a);
        ListPanelItemModelDescriptionMetadata.d(a);
    };
    ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.c = function (a) {
        a.item("Model", "ExportedType:ListPanelItemModel");
        a.item("ContentRef", "(w:Content,wf:Content)DataRef");
        a.item("AvailableWidth", "Number:double");
    };
    ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.d = function (a) {
        ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.b(a);
        a.ae("ListPanelTemplateItemUpdatingEventArgs", function () { return new ListPanelTemplateItemUpdatingEventArgsDescription(); });
        a.ad("ListPanelTemplateItemUpdatingEventArgs", ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a);
    };
    ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.$t = markType(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata, 'ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata');
    ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a = null;
    return ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata;
}(Base));
export { ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata };
